@@ -19,7 +19,7 @@ from werkzeug.middleware.proxy_fix import ProxyFix
 from injector import Binder, Injector, singleton
 from importlib.metadata import version as _pkg_version, PackageNotFoundError
 
-IATOOLKIT_VERSION = "0.67.0"
+IATOOLKIT_VERSION = "0.71.1"
 
 # global variable for the unique instance of IAToolkit
 _iatoolkit_instance: Optional['IAToolkit'] = None
@@ -91,6 +91,9 @@ class IAToolkit:
         # Step 6: initialize dispatcher and registered companies
         self._init_dispatcher_and_company_instances()
 
+        # Re-apply logging configuration in case it was modified by company-specific code
+        self._setup_logging()
+
         # Step 7: Finalize setup within the application context
         self._setup_redis_sessions()
         self._setup_cors()
@@ -155,19 +158,12 @@ class IAToolkit:
                          static_folder=static_folder,
                          template_folder=template_folder)
 
-        is_https = self._get_config_value('USE_HTTPS', 'false').lower() == 'true'
-        is_dev = self._get_config_value('FLASK_ENV') == 'development'
-
-        # get the iatoolkit domain
-        parsed_url = urlparse(os.getenv('IATOOLKIT_BASE_URL'))
-        domain = parsed_url.netloc
-
+        # get the IATOOLKIT_VERSION from the package metadata
         try:
             self.version = _pkg_version("iatoolkit")
         except PackageNotFoundError:
             pass
 
-
         self.app.config.update({
             'VERSION': self.version,
             'SECRET_KEY': self._get_config_value('FLASK_SECRET_KEY', 'iatoolkit-default-secret'),
@@ -180,6 +176,7 @@ class IAToolkit:
             'JWT_EXPIRATION_SECONDS_CHAT': int(self._get_config_value('JWT_EXPIRATION_SECONDS_CHAT', 3600))
         })
 
+        parsed_url = urlparse(os.getenv('IATOOLKIT_BASE_URL'))
         if parsed_url.scheme == 'https':
             self.app.config['PREFERRED_URL_SCHEME'] = 'https'
 
@@ -187,7 +184,7 @@ class IAToolkit:
         self.app.wsgi_app = ProxyFix(self.app.wsgi_app, x_proto=1)
 
         # Configuración para tokenizers en desarrollo
-        if is_dev:
+        if self._get_config_value('FLASK_ENV') == 'dev':
             os.environ["TOKENIZERS_PARALLELISM"] = "false"
 
     def _setup_database(self):
@@ -293,7 +290,6 @@ class IAToolkit:
         from iatoolkit.repositories.document_repo import DocumentRepo
         from iatoolkit.repositories.profile_repo import ProfileRepo
         from iatoolkit.repositories.llm_query_repo import LLMQueryRepo
-
         from iatoolkit.repositories.vs_repo import VSRepo
         from iatoolkit.repositories.tasks_repo import TaskRepo
 
@@ -318,8 +314,8 @@ class IAToolkit:
         from iatoolkit.services.branding_service import BrandingService
         from iatoolkit.services.i18n_service import I18nService
         from iatoolkit.services.language_service import LanguageService
-        from iatoolkit.services.onboarding_service import OnboardingService
         from iatoolkit.services.configuration_service import ConfigurationService
+        from iatoolkit.services.embedding_service import EmbeddingService
 
         binder.bind(QueryService, to=QueryService)
         binder.bind(TaskService, to=TaskService)
@@ -333,10 +329,10 @@ class IAToolkit:
         binder.bind(JWTService, to=JWTService)
         binder.bind(Dispatcher, to=Dispatcher)
         binder.bind(BrandingService, to=BrandingService)
-        binder.bind(OnboardingService, to=OnboardingService)
         binder.bind(I18nService, to=I18nService)
         binder.bind(LanguageService, to=LanguageService)
         binder.bind(ConfigurationService, to=ConfigurationService)
+        binder.bind(EmbeddingService, to=EmbeddingService)
 
     def _bind_infrastructure(self, binder: Binder):
         from iatoolkit.infra.llm_client import llmClient
@@ -363,7 +359,7 @@ class IAToolkit:
         # instantiate all the registered companies
         get_company_registry().instantiate_companies(self._injector)
 
-        # use the dispatcher to load the config and prepare the execution
+        # use the dispatcher to load the company config.yaml file and prepare the execution
         dispatcher = self._injector.get(Dispatcher)
         dispatcher.load_company_configs()
 
