@@ -53,14 +53,12 @@ class Company(Base):
     id = Column(Integer, primary_key=True)
     short_name = Column(String(20), nullable=False, unique=True, index=True)
     name = Column(String(256), nullable=False)
-    default_language = Column(String(5), nullable=False, default='es')
 
     # encrypted api-key
     openai_api_key = Column(String, nullable=True)
     gemini_api_key = Column(String, nullable=True)
     parameters = Column(JSON, nullable=True)
     created_at = Column(DateTime, default=datetime.now)
-    allow_jwt = Column(Boolean, default=True, nullable=True)
 
     documents = relationship("Document",
                              back_populates="company",
@@ -158,10 +156,10 @@ class Document(Base):
     company_id = Column(Integer, ForeignKey('iat_companies.id',
                     ondelete='CASCADE'), nullable=False)
     filename = Column(String(256), nullable=False, index=True)
-    content = Column(Text, nullable=False)
-    content_b64 = Column(Text, nullable=False)
     meta = Column(JSON, nullable=True)
     created_at = Column(DateTime, default=datetime.now)
+    content = Column(Text, nullable=False)
+    content_b64 = Column(Text, nullable=False)
 
     company = relationship("Company", back_populates="documents")
 
@@ -204,7 +202,10 @@ class VSDoc(Base):
     document_id = Column(Integer, ForeignKey('iat_documents.id',
                         ondelete='CASCADE'), nullable=False)
     text = Column(Text, nullable=False)
-    embedding = Column(Vector(384), nullable=False)  # Ajusta la dimensión si es necesario
+
+    # the size of this vector should be set depending on the embedding model used
+    # for OpenAI is 1536, and for huggingface is 384
+    embedding = Column(Vector(1536), nullable=False)
 
     company = relationship("Company", back_populates="vsdocs")
 
