@@ -5,6 +5,7 @@
 
 from iatoolkit.common.exceptions import IAToolkitException
 from iatoolkit.services.prompt_manager_service import PromptService
+from iatoolkit.services.sql_service import SqlService
 from iatoolkit.repositories.llm_query_repo import LLMQueryRepo
 from iatoolkit.services.configuration_service import ConfigurationService
 from iatoolkit.repositories.models import Company, Function
@@ -23,12 +24,14 @@ class Dispatcher:
                  prompt_service: PromptService,
                  llmquery_repo: LLMQueryRepo,
                  util: Utility,
+                 sql_service: SqlService,
                  excel_service: ExcelService,
                  mail_service: MailService):
         self.config_service = config_service
         self.prompt_service = prompt_service
         self.llmquery_repo = llmquery_repo
         self.util = util
+        self.sql_service = sql_service
         self.excel_service = excel_service
         self.mail_service = mail_service
         self.system_functions = _FUNCTION_LIST
@@ -40,6 +43,7 @@ class Dispatcher:
         self.tool_handlers = {
             "iat_generate_excel": self.excel_service.excel_generator,
             "iat_send_email": self.mail_service.send_mail,
+            "iat_sql_query": self.sql_service.exec_sql
         }
 
     @property
@@ -64,14 +68,42 @@ class Dispatcher:
         """Loads the configuration of every company"""
         for company_name, company_instance in self.company_instances.items():
             try:
-                # register the company configuration
-                self.config_service.register_company(company_name, company_instance)
+                # read company configuration from company.yaml
+                self.config_service.load_configuration(company_name, company_instance)
+
+                # register the company databases
+                self._register_company_databases(company_name)
+
             except Exception as e:
                 logging.error(f"❌ Failed to register configuration for '{company_name}': {e}")
                 continue
 
         return True
 
+    def _register_company_databases(self, company_name: str):
+        """
+        Reads the data_sources config for a company and registers each
+        database with the central SqlService.
+        """
+        logging.info(f"  -> Registering databases for '{company_name}'...")
+        data_sources_config = self.config_service.get_configuration(company_name, 'data_sources')
+
+        if not data_sources_config or not data_sources_config.get('sql'):
+            return
+
+        for db_config in data_sources_config['sql']:
+            db_name = db_config.get('database')
+            db_env_var = db_config.get('connection_string_env')
+
+            # resolve the URI connection string from the environment variable
+            db_uri = os.getenv(db_env_var) if db_env_var else None
+            if not db_uri:
+                logging.error(
+                    f"-> Skipping database registration for '{company_name}' due to missing 'database' name or invalid connection URI.")
+                return
+
+            self.sql_service.register_database(db_name, db_uri)
+
     def setup_iatoolkit_system(self):
         # create system functions
         for function in self.system_functions:
@@ -97,21 +129,21 @@ class Dispatcher:
             i += 1
 
 
-    def dispatch(self, company_name: str, action: str, **kwargs) -> dict:
-        company_key = company_name.lower()
+    def dispatch(self, company_short_name: str, action: str, **kwargs) -> dict:
+        company_key = company_short_name.lower()
 
         if company_key not in self.company_instances:
             available_companies = list(self.company_instances.keys())
             raise IAToolkitException(
                 IAToolkitException.ErrorType.EXTERNAL_SOURCE_ERROR,
-                f"Empresa '{company_name}' no configurada. Empresas disponibles: {available_companies}"
+                f"Empresa '{company_short_name}' no configurada. Empresas disponibles: {available_companies}"
             )
 
         # check if action is a system function
         if action in self.tool_handlers:
             return  self.tool_handlers[action](**kwargs)
 
-        company_instance = self.company_instances[company_name]
+        company_instance = self.company_instances[company_short_name]
         try:
             return company_instance.handle_request(action, **kwargs)
         except IAToolkitException as e:
@@ -123,37 +155,6 @@ class Dispatcher:
             raise IAToolkitException(IAToolkitException.ErrorType.EXTERNAL_SOURCE_ERROR,
                                f"Error en function call '{action}': {str(e)}") from e
 
-    def get_company_context(self, company_name: str, **kwargs) -> str:
-        if company_name not in self.company_instances:
-            raise IAToolkitException(IAToolkitException.ErrorType.EXTERNAL_SOURCE_ERROR,
-                               f"Empresa no configurada: {company_name}")
-
-        company_context = ''
-
-        # read the company context from this list of markdown files,
-        # company brief, credits, operation description, etc.
-        context_dir = os.path.join(os.getcwd(), f'companies/{company_name}/context')
-        context_files = self.util.get_files_by_extension(context_dir, '.md', return_extension=True)
-        for file in context_files:
-            filepath = os.path.join(context_dir, file)
-            company_context += self.util.load_markdown_context(filepath)
-
-        # add the schemas for every table or function call responses
-        schema_dir = os.path.join(os.getcwd(), f'companies/{company_name}/schema')
-        schema_files = self.util.get_files_by_extension(schema_dir, '.yaml', return_extension=True)
-        for file in schema_files:
-            schema_name = file.split('_')[0]
-            filepath = os.path.join(schema_dir, file)
-            company_context += self.util.generate_context_for_schema(schema_name, filepath)
-
-        company_instance = self.company_instances[company_name]
-        try:
-            return company_context + company_instance.get_company_context(**kwargs)
-        except Exception as e:
-            logging.exception(e)
-            raise IAToolkitException(IAToolkitException.ErrorType.EXTERNAL_SOURCE_ERROR,
-                               f"Error getting company context of: {company_name}: {str(e)}") from e
-
     def get_company_services(self, company: Company) -> list[dict]:
         # create the syntax with openai response syntax, for the company function list
         tools = []
@@ -189,25 +190,11 @@ class Dispatcher:
 
         return external_user_profile
 
-    def get_metadata_from_filename(self, company_name: str, filename: str) -> dict:
-        if company_name not in self.company_instances:
-            raise IAToolkitException(IAToolkitException.ErrorType.EXTERNAL_SOURCE_ERROR,
-                               f"company not configured: {company_name}")
-
-        company_instance = self.company_instances[company_name]
-        try:
-            return company_instance.get_metadata_from_filename(filename)
-        except Exception as e:
-            logging.exception(e)
-            raise IAToolkitException(IAToolkitException.ErrorType.EXTERNAL_SOURCE_ERROR,
-                               f"Error in get_metadata_from_filename: {company_name}: {str(e)}") from e
-
     def get_company_instance(self, company_name: str):
         """Returns the instance for a given company name."""
         return self.company_instances.get(company_name)
 
 
-
 # iatoolkit system prompts
 _SYSTEM_PROMPT = [
     {'name': 'query_main', 'description':'iatoolkit main prompt'},
@@ -215,17 +202,34 @@ _SYSTEM_PROMPT = [
     {'name': 'sql_rules', 'description':'instructions  for SQL queries'}
 ]
 
-# iatoolkit  function calls
+# iatoolkit  built-in functions (Tools)
 _FUNCTION_LIST = [
     {
-        "name": "iat_generate_excel",
+        "function_name": "iat_sql_query",
+        "description": "Servicio SQL de IAToolkit: debes utilizar este servicio para todas las consultas a base de datos.",
+        "parameters": {
+            "type": "object",
+            "properties": {
+                "database": {
+                    "type": "string",
+                    "description": "nombre de la base de datos a consultar: `database_name`"
+                },
+                "query": {
+                    "type": "string",
+                    "description": "string con la consulta en sql"
+                },
+            },
+            "required": ["database", "query"]
+            }
+    },
+    {
+        "function_name": "iat_generate_excel",
         "description": "Generador de Excel."
                     "Genera un archivo Excel (.xlsx) a partir de una lista de diccionarios. "
                     "Cada diccionario representa una fila del archivo. "
                     "el archivo se guarda en directorio de descargas."
                     "retorna diccionario con filename, attachment_token (para enviar archivo por mail)"
                     "content_type y download_link",
-        "function_name": "iat_generate_excel",
         "parameters": {
             "type": "object",
             "properties": {
@@ -265,11 +269,10 @@ _FUNCTION_LIST = [
         }
     },
     {
-        'name': 'Envio de mails',
-         'description':  "iatoolkit mail system. "        
+        'function_name': "iat_send_email",
+        'description':  "iatoolkit mail system. "        
             "envia mails cuando un usuario lo solicita."
             "Si no te indican quien envia el correo utiliza la dirección iatoolkit@iatoolkit.com",
-         'function_name': "iat_send_email",
          'parameters': {
             "type": "object",
             "properties": {
