@@ -12,7 +12,7 @@ from iatoolkit.services.jwt_service import JWTService
 from iatoolkit.services.query_service import QueryService
 from iatoolkit.services.prompt_manager_service import PromptService
 from iatoolkit.services.branding_service import BrandingService
-from iatoolkit.services.onboarding_service import OnboardingService
+from iatoolkit.services.configuration_service import ConfigurationService
 from iatoolkit.services.i18n_service import I18nService
 from iatoolkit.views.base_login_view import BaseLoginView
 import logging
@@ -29,7 +29,7 @@ class LoginView(BaseLoginView):
             return render_template('error.html',
                                    message=self.i18n_service.t('errors.templates.company_not_found')), 404
 
-        branding_data = self.branding_service.get_company_branding(company)
+        branding_data = self.branding_service.get_company_branding(company_short_name)
         email = request.form.get('email')
         password = request.form.get('password')
 
@@ -61,7 +61,7 @@ class LoginView(BaseLoginView):
 
         # 2. Delegate the path decision to the centralized logic.
         try:
-            return self._handle_login_path(company, user_identifier, target_url)
+            return self._handle_login_path(company_short_name, user_identifier, target_url)
         except Exception as e:
             message = self.i18n_service.t('errors.templates.processing_error', error=str(e))
             return render_template(
@@ -83,7 +83,7 @@ class FinalizeContextView(MethodView):
                  query_service: QueryService,
                  prompt_service: PromptService,
                  branding_service: BrandingService,
-                 onboarding_service: OnboardingService,
+                 config_service: ConfigurationService,
                  jwt_service: JWTService,
                  i18n_service: I18nService
                  ):
@@ -92,7 +92,7 @@ class FinalizeContextView(MethodView):
         self.query_service = query_service
         self.prompt_service = prompt_service
         self.branding_service = branding_service
-        self.onboarding_service = onboarding_service
+        self.config_service = config_service
         self.i18n_service = i18n_service
 
     def get(self, company_short_name: str, token: str = None):
@@ -111,7 +111,7 @@ class FinalizeContextView(MethodView):
 
                 user_identifier = payload.get('user_identifier')
             else:
-                logging.warning("Fallo crítico: missing session information or auth token")
+                logging.error("missing session information or auth token")
                 return redirect(url_for('home', company_short_name=company_short_name))
 
             company = self.profile_service.get_company_by_short_name(company_short_name)
@@ -119,17 +119,17 @@ class FinalizeContextView(MethodView):
                 return render_template('error.html',
                             company_short_name=company_short_name,
                             message="Empresa no encontrada"), 404
-            branding_data = self.branding_service.get_company_branding(company)
+            branding_data = self.branding_service.get_company_branding(company_short_name)
 
             # 2. Finalize the context rebuild (the heavy task).
-            self.query_service.finalize_context_rebuild(
+            self.query_service.set_context_for_llm(
                 company_short_name=company_short_name,
                 user_identifier=user_identifier
             )
 
             # 3. render the chat page.
             prompts = self.prompt_service.get_user_prompts(company_short_name)
-            onboarding_cards = self.onboarding_service.get_onboarding_cards(company)
+            onboarding_cards = self.config_service.get_configuration(company_short_name, 'onboarding_cards')
 
             # Get the entire 'js_messages' block in the correct language.
             js_translations = self.i18n_service.get_translation_block('js_messages')
